Attribute VB_Name = "Module1"
'**********************************************************************
' Module    : S2600.bas
' Platform  : VB6 -- NOT COMPATIBLE WITH VB.NET!
' Function  : Include file for VB projects that use S2600.DLL
' Copyright : (C) 2005 Sensoray
'**********************************************************************

Option Explicit

' Maximum number of transaction retries permitted.
Public Const DEFAULT_RETRIES = 1

' Gateway's IOM identifier.
Public Const IOM_GATEWAY = &HFF

' IOM status bit masks.
Public Const STATUS_RST = &H80
Public Const STATUS_CERR = &H40

' Serial comport LED control bits.
Public Const SIOLED_XMT = 8
Public Const SIOLED_RCV = 4
Public Const SIOLED_ERR = 2

' Transaction error codes.
Public Const GWERR_NONE = &H0&              ' No gateway errors detected.
Public Const GWERR_TOOLARGE = &H100&        ' Too many MCmds in a command packet, or cmd/rsp packet exceeds MM max allowed size.
Public Const GWERR_XACTALLOC = &H300&       ' Couldn't allocate transaction object.
Public Const GWERR_IOMNORESPOND = &H400&    ' Bad module response, ModID is in LSB of ErrorCode.
Public Const GWERR_MMCLOSED = &H500&        ' MM is not open.
Public Const GWERR_IOMCLOSED = &H600&       ' Iom is not open.
Public Const GWERR_IOMTYPE = &H700&         ' Action is not supported by the registered iom type.
Public Const GWERR_IOMCERR = &H800&         ' Iom comm error flag (CERR) is asserted.  See IomStatus[] for details.
Public Const GWERR_IOMRESET = &H900&        ' Module's (iom or mm) reset flag (RST) is asserted.  See IomStatus[] for details in case of iom.
Public Const GWERR_MMNORESPOND = &HA00&     ' MM response timed out.
Public Const GWERR_PACKETSEND = &HB00&      ' Socket driver failed to send command packet.
Public Const GWERR_IOMSPECIFIC = &HC00&     ' Iom-specific status flag is asserted.  See IomStatus[] for details.
Public Const GWERR_BADVALUE = &HD00&        ' Illegal arg value (e.g., chan no. doesn't exist, bad MM handle), ArgID is in LSB or ErrorCode.

Public Const GWERR_MASK = &HFFFFFF00        ' Mask used to isolate the error code from LSB, which may contain additional info.

' Serial comport mode control bits --------

Public Const SIO_BR_300 = &H300
Public Const SIO_BR_600 = &H180
Public Const SIO_BR_1200 = &HC0
Public Const SIO_BR_2400 = &H60
Public Const SIO_BR_4800 = &H30
Public Const SIO_BR_9600 = &H18
Public Const SIO_BR_19200 = &HC
Public Const SIO_BR_38400 = 6
Public Const SIO_BR_57600 = 4
Public Const SIO_BR_115200 = 2

Public Const SIOMODE_PHY_SHIFT = &H40
Public Const SIOMODE_RS232 = SIOMODE_PHY_SHIFT * 0              ' RS232, full-duplex.
Public Const SIOMODE_RS422_IDLEON = SIOMODE_PHY_SHIFT * 1       ' RS422, full-duplex, transmitter always enabled.
Public Const SIOMODE_RS4XX_HDX_IDLEOFF = SIOMODE_PHY_SHIFT * 2  ' RS422/485, half-duplex, transmitter tri-stated when idle.
Public Const SIOMODE_RS4XX_FDX_IDLEOFF = SIOMODE_PHY_SHIFT * 3  ' RS422/485, full-duplex, transmitter tri-stated when idle.

Public Const SIOMODE_FLOWCTRL_SHIFT = &H20
Public Const SIOMODE_FLOWCTRL = SIOMODE_FLOWCTRL_SHIFT * 1      ' xon/xoff

Public Const SIOMODE_PAR_SHIFT = 8
Public Const SIOMODE_PAR_NONE = SIOMODE_PAR_SHIFT * 0
Public Const SIOMODE_PAR_ODD = SIOMODE_PAR_SHIFT * 1
Public Const SIOMODE_PAR_EVEN = SIOMODE_PAR_SHIFT * 3

Public Const SIOMODE_STOP_SHIFT = 4
Public Const SIOMODE_STOP_1 = SIOMODE_STOP_SHIFT * 0
Public Const SIOMODE_STOP_2 = SIOMODE_STOP_SHIFT * 1

Public Const SIOMODE_DATA_5 = 0
Public Const SIOMODE_DATA_6 = 1
Public Const SIOMODE_DATA_7 = 2
Public Const SIOMODE_DATA_8 = 3

' 2608 analog input sample types.
Public Const ADC_SNAPSHOTS = False
Public Const ADC_INTEGRATEDS = True

' 2620 soft triggers for S26_Sched2620_SetControlReg().
Public Const CTC_TRIG_PRELOAD = 1
Public Const CTC_TRIG_LATCH = 2

'***************************************************************************
' Functions in S2600.DLL
'***************************************************************************

' Initialization and shutdown.
Declare Function S26_DriverOpen Lib "S2600.DLL" (ByVal NumMMs As Long) As Long
Declare Sub S26_DriverClose Lib "S2600.DLL" ()
Declare Function S26_BoardOpen Lib "S2600.DLL" (ByVal hbd As Long, ByVal ClientDotAdrs As String, ByVal MMDotAdrs As String) As Long

Declare Function S26_DriverVersion Lib "S2600.DLL" () As String


Declare Sub S26_BoardClose Lib "S2600.DLL" (ByVal hbd As Long)
Declare Function S26_RegisterAllIoms Lib "S2600.DLL" (ByVal hbd As Long, ByVal Milliseconds As Long, ByRef NumBoards As Integer, ByRef IomTypeList As Integer, ByRef IomStatus As Byte, ByVal Retries As Long) As Long
Declare Function S26_ResetIom Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal Retries As Long) As Long
Declare Function S26_ResetNetwork Lib "S2600.DLL" (ByVal hbd As Long) As Long

' Asynchronous serial communications.
Declare Function S26_ComSetMode Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal ClockDiv As Integer, ByVal Attributes As Byte, ByVal LEDs As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComSetBreakChar Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal BreakChar As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComSend Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal MsgBuf As String, ByVal MsgLen As Integer, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComReceive Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal MsgBuf As String, ByRef MsgLen As Integer, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComClearFlags Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComOpen Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComClose Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComFlush Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComStartBreak Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComEndBreak Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComGetRxCount Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByRef CharCount As Integer, ByVal Milliseconds As Long, ByVal Retries As Long) As Long
Declare Function S26_ComGetTxCount Lib "S2600.DLL" (ByVal hbd As Long, ByVal LogDev As Byte, ByRef CharCount As Integer, ByVal Milliseconds As Long, ByVal Retries As Long) As Long

' VB type casting and utility.
Declare Function Bitmask32 Lib "S2600.DLL" Alias "S26_Bitmask" (ByVal BitNum As Long) As Long
Declare Function CastAsLong Lib "S2600.DLL" Alias "S26_CastAsLong" (ByRef Value As Any) As Long
Declare Function CastAsShort Lib "S2600.DLL" Alias "S26_CastAsShort" (ByRef Value As Any) As Integer
Declare Sub CopyAny Lib "S2600.DLL" Alias "S26_CopyAny" (ByRef Dest As Any, ByRef Src As Any, ByVal nbytes As Long)

' Gateway transaction functions ----------------------------------

' Transaction control.
Declare Function S26_SchedOpen Lib "S2600.DLL" (ByVal hbd As Long, ByVal Retries As Long) As Long
Declare Function S26_SchedExecute Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal msec As Long, ByRef IomStatus As Byte) As Long
Declare Function S26_SchedExecuteStart Lib "S2600.DLL" (ByVal hTransaction As Long) As Long
Declare Function S26_SchedExecuteIsResponded Lib "S2600.DLL" (ByVal hTransaction As Long) As Long
Declare Function S26_SchedExecuteWait Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal Milliseconds As Long) As Long
Declare Function S26_SchedExecuteFinish Lib "S2600.DLL" (ByVal hTransaction As Long, ByRef IomStatus As Byte) As Long

' General-purpose IOM transactions.
Declare Function S26_Sched2600_Nop Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte) As Long
Declare Function S26_Sched2600_ClearStatus Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal BitMask As Byte) As Long
Declare Function S26_Sched2600_IomGetProductID Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef ProductID As Integer) As Long
Declare Function S26_Sched2600_GetFirmwareVersion Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Version As Integer) As Long
Declare Function S26_Sched2600_GetAddress Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Adrs As Byte) As Long

' 2601 MM.
Declare Function S26_Sched2601_GetLinkStatus Lib "S2600.DLL" (ByVal hTransaction As Long, ByRef LinkFlags As Integer) As Long
Declare Function S26_Sched2601_GetInterlocks Lib "S2600.DLL" (ByVal hTransaction As Long, ByRef LockFlags As Byte) As Long
Declare Function S26_Sched2601_SetWatchdog Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal NumTenthSeconds As Byte) As Long

' 2608 analog I/O.
Declare Function S26_2608_AdcCorrect Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal RawData As Integer, ByVal IsHighGain As Long) As Double
Declare Function S26_2608_WriteEeprom Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal address As Byte, ByVal Value As Byte, ByVal Retries As Long) As Long
Declare Function S26_Sched2608_GetAins Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Volts As Double, ByVal Integrated As Long) As Long
Declare Function S26_Sched2608_GetAinTypes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef types As Byte) As Long
Declare Function S26_Sched2608_GetAout Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef Volts As Double) As Long
Declare Function S26_Sched2608_GetCalData Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef CalData As Integer) As Long
Declare Function S26_Sched2608_ReadEeprom Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal address As Byte, ByRef Value As Byte) As Long
Declare Function S26_Sched2608_SetAinTypes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef types As Byte) As Long
Declare Function S26_Sched2608_SetAout Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal Volts As Double) As Long
Declare Function S26_Sched2608_SetLineFreq Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal freq As Byte) As Long
Declare Function S26_Sched2608_SetTempUnits Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal DegreesF As Long) As Long

' 2610 digital I/O.
Declare Function S26_Sched2610_GetInputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2610_GetModes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2610_GetModes32 Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2610_GetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2610_GetPwmRatio Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef OnTime As Byte, ByRef OffTime As Byte) As Long
Declare Function S26_Sched2610_SetModes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2610_SetModes32 Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Any) As Long
Declare Function S26_Sched2610_SetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2610_SetPwmRatio Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal OnTime As Byte, ByVal OffTime As Byte) As Long

' 2612 analog input.
Declare Function S26_Sched2612_SetMode Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal mode As Long) As Long
Declare Function S26_Sched2612_SetVoltages Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Volts As Byte) As Long
Declare Function S26_Sched2612_GetValues Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef values As Long, ByRef tstamps As Byte) As Long
Declare Function S26_Sched2612_RefreshData Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte) As Long
Declare Function S26_2612_RegisterZero Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal Chan As Byte, ByVal NSMP As Long) As Long
Declare Function S26_2612_RegisterSpan Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal Chan As Byte, ByVal NSMP As Long, ByVal load As Double) As Long
Declare Function S26_2612_RegisterTare Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal Chan As Byte, ByVal NSMP As Long) As Long
Declare Function S26_2612_SaveCalibrations Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal Chan As Byte) As Long
Declare Function S26_2612_RestoreCalibrations Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal msec As Long, ByVal Chan As Byte) As Long
Declare Function S26_2612_GetCalibratedValue Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef sample As Long) As Double
Declare Function S26_2612_GetOffset Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal Chan As Byte) As Double
Declare Function S26_2612_GetScale Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal Chan As Byte) As Double
Declare Function S26_2612_GetTare Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal Chan As Byte) As Double
Declare Function S26_2612_SetCalibrations Lib "S2600.DLL" (ByVal hbd As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal Offset As Double, ByVal ScaleVal As Double, ByVal Tare As Double) As Long

' 2620 counter.
Declare Function S26_Sched2620_GetCommonControl Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef period As Integer, ByRef tstamp As Byte) As Long
Declare Function S26_Sched2620_GetCounts Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef Value As Long, ByRef TimeStamp As Integer) As Long
Declare Function S26_Sched2620_GetMode Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef mode As Integer) As Long
Declare Function S26_Sched2620_GetPreload Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal reg As Byte, ByRef Value As Long) As Long
Declare Function S26_Sched2620_GetStatus Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef Status As Integer) As Long
Declare Function S26_Sched2620_SetCommonControl Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal period As Integer, ByVal tstamp As Byte) As Long
Declare Function S26_Sched2620_SetControlReg Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal DataVal As Byte) As Long
Declare Function S26_Sched2620_SetMode Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal mode As Integer) As Long
Declare Function S26_Sched2620_SetModeEncoder Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal ActLowX As Integer, ByVal HardPreload As Integer, ByVal ClkMode As Integer) As Long
Declare Function S26_Sched2620_SetModeFreqMeas Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal InternalGate As Integer) As Long
Declare Function S26_Sched2620_SetModePeriodMeas Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal ActLowX As Integer) As Long
Declare Function S26_Sched2620_SetModePulseGen Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal ActLowX As Integer, HardTrig As Integer, ByVal ActLowOut As Integer) As Long
Declare Function S26_Sched2620_SetModePulseMeas Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal ActLowX As Integer) As Long
Declare Function S26_Sched2620_SetModePwmGen Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal ActLowOut As Integer) As Long
Declare Function S26_Sched2620_SetPreload Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal reg As Byte, ByVal Value As Long) As Long

' 2631 motor controller.
Declare Function S26_Sched2631_SetControlReg Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal DataVal As Byte) As Long
Declare Function S26_Sched2631_GetStatus Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Status As Integer) As Long
Declare Function S26_Sched2631_SetPreload Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal reg As Byte, ByVal Value As Long) As Long
Declare Function S26_Sched2631_GetPreload Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal reg As Byte, ByRef Value As Long) As Long
Declare Function S26_Sched2631_GetCounts Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Value As Long, ByRef tstamp As Integer) As Long
Declare Function S26_Sched2631_SetCommonControl Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal period As Integer, ByVal tstamp As Byte) As Long
Declare Function S26_Sched2631_GetCommonControl Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef period As Integer, ByRef tstamp As Byte) As Long
Declare Function S26_Sched2631_SetMode Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal mode As Integer) As Long
Declare Function S26_Sched2631_GetMode Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef mode As Integer) As Long
Declare Function S26_Sched2631_SetModeEncoder Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal ActLowX As Integer, ByVal HardPreload As Integer, ByVal ClkMode As Integer) As Long
Declare Function S26_Sched2631_SetModePulseGen Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal ActLowX As Integer, ByVal HardTrig As Integer, ByVal ActLowOut As Integer) As Long
Declare Function S26_Sched2631_SetModePwmGen Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal ActLowOut As Integer) As Long
Declare Function S26_Sched2631_SetModePulseMeas Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal ActLowX As Integer) As Long
Declare Function S26_Sched2631_SetModePeriodMeas Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal ActLowX As Integer) As Long
Declare Function S26_Sched2631_SetModeFreqMeas Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal igate As Integer) As Long
Declare Function S26_Sched2631_OutEnable Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal enable As Byte) As Long
Declare Function S26_Sched2631_SetOutMode Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal mode As Byte) As Long
Declare Function S26_Sched2631_SetAmpl Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal amplitude As Long) As Long
Declare Function S26_Sched2631_SetOutputFrq Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal frequency As Long) As Long
Declare Function S26_Sched2631_SetPWMFrq Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal frequency As Long) As Long

' 2650 relay.
Declare Function S26_Sched2650_GetInputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2650_GetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2650_SetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long

' 2652 ssr I/O
Declare Function S26_Sched2652_GetInputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2652_GetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2652_SetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2652_GetModes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2652_GetPwmRatio Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef OnTime As Byte, ByRef OffTime As Byte) As Long
Declare Function S26_Sched2652_SetModes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2652_SetPwmRatio Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal OnTime As Byte, ByVal OffTime As Byte) As Long

' 2653 ssr I/O
Declare Function S26_Sched2653_GetInputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2653_GetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2653_SetOutputs Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef States As Byte) As Long
Declare Function S26_Sched2653_GetModes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2653_GetPwmRatio Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByRef OnTime As Byte, ByRef OffTime As Byte) As Long
Declare Function S26_Sched2653_SetModes Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByRef Modes As Byte) As Long
Declare Function S26_Sched2653_SetPwmRatio Lib "S2600.DLL" (ByVal hTransaction As Long, ByVal IomPort As Byte, ByVal Chan As Byte, ByVal OnTime As Byte, ByVal OffTime As Byte) As Long



'***************************************************************************
' Helper functions for DIO and relay modules
'***************************************************************************

Public Function GetBit(ByteArray() As Byte, Chan As Integer) As Integer
    GetBit = ((ByteArray(Chan \ 8) And (2 ^ (Chan And 7))) <> 0) And 1
End Function

Public Sub SetBit(ByteArray() As Byte, Chan As Integer, Val As Integer)
    Dim ByteNum As Integer
    Dim BitMask As Byte
    ByteNum = Chan \ 8
    BitMask = 2 ^ (Chan And 7)
    If (Val <> 0) Then
        ByteArray(ByteNum) = ByteArray(ByteNum) Or BitMask
    Else
        ByteArray(ByteNum) = ByteArray(ByteNum) And Not BitMask
    End If
End Sub

Public Sub Fill(ByteArray() As Byte, b As Byte)
    Dim i As Integer
    For i = 0 To UBound(ByteArray)
        ByteArray(i) = b
    Next i
End Sub

